import { get, post } from "@/api/index";

export default {
    /**
     * 单品列表 
     * @param {String} params.PageSize
     * @param {String} params.CurrentIndex
     * @param {String} params.ProductType 产品类型
     * @param {String} params.KeyWord 搜索关键字
     * @param {String} params.SortType 排序类型
     * @param {String} params.SaleStatus 状态
     * @param {String} params.IsSingle 是否是单品产品
     * @param {String} params.UpdatedTime 更新时间
     * @param {String} params.CreatedTime 创建时间
     * @returns 
     */
    getproductList:params=>{
        return get('/product/productList',params)
    },
    /**
     * 获取未设置的产品列表
     * @param {Object} params
     * @param {String} params.PageSize
     * @param {String} params.CurrentIndex
     * @param {String} params.ProductType 类型
     * @param {String} params.PermissionIds 品种id
     * @param {String} params.KeyWord 搜索关键字
     * @returns 
     */
    getUnSetProductList:params=>{
        return get('/product/unSetProductList',params)
    },
    /**
     * 增加单品产品 
     * @param {Object} params
     * @param {String} params.Type 类型
     * @param {String} params.Price 价格
     * @param {String} params.SourceId 产品id
     * @returns 
     */
    postAddProduct:params=>{
        return post('/product/addProduct',params)
    },
    /**
     * 上下架产品
     * @param {String} params.SaleStatus 状态
     * @param {String} params.ProductId 产品id
     * @returns 
     */
    postUpdateSaleStatus:params=>{
        return post('/product/updateSaleStatus',params)
    },
    /**
     * 删除产品
     * @param {String} params.ProductId 产品id
     * @returns 
     */
    postDeleteProduct:params=>{
        return post('/product/deleteProduct',params)
    },
    /**
     * 增加产品 
     * @param {String} params.SourceId
     * @param {String} params.Type
     * @param {String} params.ProductName 类型
     * @param {String} params.CoverSrc 品种id
     * @param {String} params.ValidDays 搜索关键字
     * @param {String} params.Price 搜索关键字
     * @param {String} params.Description 搜索关键字
     * @returns 
     */
    postAddProduct:params=>{
        return post('/product/addProduct',params)
    },
    /**
     * 编辑产品 
     * @param {String} params.SourceId
     * @param {String} params.Type
     * @param {String} params.ProductName 类型
     * @param {String} params.CoverSrc 品种id
     * @param {String} params.ValidDays 搜索关键字
     * @param {String} params.Price 搜索关键字
     * @param {String} params.Description 搜索关键字
     * @returns 
     */
    postEditProduct:params=>{
        return post('/product/editProduct',params)
    },
    /**
     * 上传图片
     * @param {Object} params
     * @param {String} params.file 文件
     * @returns 
     * */
    postUploadFile:params=>{
        return post('/product/uploadFile',params)
    },
    /**
     * 获取产品最新风险等级 
     * @param {Object} params
     * @param {String} params.SourceId 品种id
     * @param {String} params.ProductType 产品类型
     * @returns 
     * */
    getRiskLevel:params=>{
        return get('/product/productRisk',params)
    }
};
